#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-IAQhQgcCmqp3uScoOG7Klu
key:                  raw-strings-qq-1.1-IAQhQgcCmqp3uScoOG7Klu
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  29590c8c7456d0c4b2389f895a49bac2
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/raw-strings-qq-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-raw-strings-qq
hs-libraries:         HSraw-strings-qq-1.1-IAQhQgcCmqp3uScoOG7Klu
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

